@@ -19,6 +19,7 @@ import logging
 import pytest
 
 from twine import exceptions
+from twine import repository
 from twine import settings
 
 
@@ -76,11 +77,44 @@ def test_settings_transforms_repository_config_non_pypi(write_config_file):
     assert s.identity is None
     assert s.username == "someusername"
     assert s.password == "password"
-    assert s.cacert is None
     assert s.client_cert is None
     assert s.disable_progress_bar is False
 
 
+def test_settings_verify_feature_compatibility() -> None:
+    s = settings.Settings(skip_existing=True)
+    s.repository_config = {"repository": repository.WAREHOUSE}
+    try:
+        s.verify_feature_capability()
+    except exceptions.UnsupportedConfiguration as unexpected_exc:
+        pytest.fail(
+            "Expected feature capability to work with production PyPI"
+            f" but got {unexpected_exc!r}"
+        )
+
+    s.repository_config["repository"] = repository.TEST_WAREHOUSE
+    try:
+        s.verify_feature_capability()
+    except exceptions.UnsupportedConfiguration as unexpected_exc:
+        pytest.fail(
+            "Expected feature capability to work with TestPyPI but got"
+            f" {unexpected_exc!r}"
+        )
+
+    s.repository_config["repository"] = "https://not-really-pypi.example.com/legacy"
+    with pytest.raises(exceptions.UnsupportedConfiguration):
+        s.verify_feature_capability()
+
+    s.skip_existing = False
+    try:
+        s.verify_feature_capability()
+    except exceptions.UnsupportedConfiguration as unexpected_exc:
+        pytest.fail(
+            "Expected an exception only when --skip-existing is provided"
+            f" but got {unexpected_exc!r}"
+        )
+
+
 @pytest.mark.parametrize(
     "verbose, log_level", [(True, logging.INFO), (False, logging.WARNING)]
 )
